from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, Int, File, String, Directory

Run_Discosnp___Sh_V0_1_0 = CommandToolBuilder(tool="run_discoSnp++.sh", base_command=["run_discoSnp++.sh"], inputs=[ToolInput(tag="in_f_of", input_type=Boolean(optional=True), prefix="--fof", doc=InputDocumentation(doc="<file name of a file of file(s)>\nThe input read files indicated in a file of file(s)\nExample: -r bank.fof with bank.fof containing the two lines\ndata_sample/reads_sequence1.fasta\ndata_sample/reads_sequence2.fasta.gz")), ToolInput(tag="in_k_size", input_type=Int(optional=True), prefix="--k_size", doc=InputDocumentation(doc="<int value>\nSet the length of used kmers. Must fit the compiled value.\nDefault=31")), ToolInput(tag="in_min_coverage", input_type=Int(optional=True), prefix="--min_coverage", doc=InputDocumentation(doc="<int value>\nSet the minimal coverage per read set: Used by kissnp2 (don't use kmers with lower coverage) and kissreads (read coherency threshold).\nThis coverage can be automatically detected per read set (in this case use 'auto' or specified per read set, see the documentation.\nDefault=3")), ToolInput(tag="in_max_coverage", input_type=Int(optional=True), prefix="--max_coverage", doc=InputDocumentation(doc="<int value in 0, 1 or 2>\nSet the maximal coverage for each read set: Used by kissnp2 (don't use kmers with higher coverage).\nDefault=2^31-1")), ToolInput(tag="in_branching", input_type=Int(optional=True), prefix="--branching", doc=InputDocumentation(doc="0: forbid variants for which any of the two paths is branching (high precision, lowers the recall in complex genomes).\nDefault value\n1: (smart branching) forbid SNPs for which the two paths are branching (e.g. the two paths can be created either with a 'A' or a 'C' at the same position\n2: No limitation on branching (lowers the precision, high recall)")), ToolInput(tag="in_symmetrical", input_type=Int(optional=True), prefix="--symmetrical", doc=InputDocumentation(doc="<int value>\nIn -b 2 mode only: maximal number of symmetrical crossroads traversed while trying to close a bubble. Default: no limit")), ToolInput(tag="in_graph", input_type=File(optional=True), prefix="--graph", doc=InputDocumentation(doc="Reuse a previously created graph (.h5 file)")), ToolInput(tag="in_stop_discosnp_right", input_type=File(optional=True), prefix="-X", doc=InputDocumentation(doc="Stop discoSnp++ right after variant calling - the output is only a fasta file with no coverage information.")), ToolInput(tag="in_deletion_max_size", input_type=Int(optional=True), prefix="--deletion_max_size", doc=InputDocumentation(doc="discoSnp++ will search for deletions of size from 0 to D included. -D 0 means no deletion detected. Default=100.")), ToolInput(tag="in_ambiguity_max_size", input_type=Int(optional=True), prefix="--ambiguity_max_size", doc=InputDocumentation(doc="Maximal size of ambiguity of INDELs. INDELS whose ambiguity is higher than this value are not output  [default '20']")), ToolInput(tag="in_max_snp_per_bubble", input_type=Int(optional=True), prefix="--max_snp_per_bubble", doc=InputDocumentation(doc="discoSnp++ will search up to P SNPs in a unique bubble. Default=3")), ToolInput(tag="in_f_of_mapping", input_type=Boolean(optional=True), prefix="--fof_mapping", doc=InputDocumentation(doc="<file name of a file of file(s)>\nIf this option is used this fof is used when mapping back reads on the predicted variants instead of the original fof file provided by -r|--fof option")), ToolInput(tag="in_prefix", input_type=String(optional=True), prefix="--prefix", doc=InputDocumentation(doc="All out files will start with this prefix. Default='discoRes'")), ToolInput(tag="in_no_low_complexity", input_type=Boolean(optional=True), prefix="--no_low_complexity", doc=InputDocumentation(doc="Remove low complexity bubbles")), ToolInput(tag="in_contigs", input_type=Boolean(optional=True), prefix="--contigs", doc=InputDocumentation(doc="Extend found polymorphisms with contigs (default: extend with unitigs)")), ToolInput(tag="in_max_substitutions", input_type=Int(optional=True), prefix="--max_substitutions", doc=InputDocumentation(doc="Set the number of authorized substitutions used while mapping reads on found SNPs (kissreads). Default=1")), ToolInput(tag="in_no_genotype", input_type=Boolean(optional=True), prefix="--no_genotype", doc=InputDocumentation(doc="Do not compute the genotypes")), ToolInput(tag="in_max_threads", input_type=Int(optional=True), prefix="--max_threads", doc=InputDocumentation(doc="Max number of used threads. 0 means all threads\ndefault 0")), ToolInput(tag="in_reference_genome", input_type=File(optional=True), prefix="--reference_genome", doc=InputDocumentation(doc="Reference genome file (fasta, fastq, gzipped or nor). In absence of this file the VCF created by VCF_creator won't contain mapping related results.")), ToolInput(tag="in_use_reference_file", input_type=Boolean(optional=True), prefix="-R", doc=InputDocumentation(doc="Use the reference file also in the variant calling, not only for mapping results")), ToolInput(tag="in_bwa_path", input_type=Directory(optional=True), prefix="--bwa_path", doc=InputDocumentation(doc="bwa path. e.g. /home/me/my_programs/bwa-0.7.12/ (note that bwa must be pre-compiled)\nOptional unless option -G used and bwa is not in the binary path.")), ToolInput(tag="in_map_variant_predictions", input_type=Boolean(optional=True), prefix="-e", doc=InputDocumentation(doc="Map variant predictions on reference genome with their unitig or contig extensions.\nUseless unless mapping on reference genome is required (option -G).")), ToolInput(tag="in_wraith_mode_only", input_type=Boolean(optional=True), prefix="-w", doc=InputDocumentation(doc="Wraith mode: only show all discoSnp++ commands without running them")), ToolInput(tag="in_verbose_avoids_output", input_type=Int(optional=True), prefix="-v", doc=InputDocumentation(doc="Verbose 0 (avoids progress output) or 1 (enables progress output) -- default=1."))], outputs=[ToolOutput(tag="out_stop_discosnp_right", output_type=File(optional=True), selector=InputSelector(input_to_select="in_stop_discosnp_right", type_hint=File()), doc=OutputDocumentation(doc="Stop discoSnp++ right after variant calling - the output is only a fasta file with no coverage information."))], container="quay.io/biocontainers/discosnp:2.5.4--h8b12597_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Run_Discosnp___Sh_V0_1_0().translate("wdl")

